pm4py.algo.comparison.petrinet package
======================================

Submodules
----------

pm4py.algo.comparison.petrinet.element\_usage\_comparison module
----------------------------------------------------------------

.. automodule:: pm4py.algo.comparison.petrinet.element_usage_comparison
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.comparison.petrinet
   :members:
   :undoc-members:
   :show-inheritance:
